﻿//INSTANT C# NOTE: Formerly VB project-level imports:
using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Drawing;
using System.Diagnostics;
using System.Windows.Forms;
using System.Linq;
using System.Xml.Linq;

using System.Data.OleDb;

namespace WindowsApplication1
{
    public partial class Form1
    {

        internal Form1()
        {
            InitializeComponent();
        }

    #region  Event Handlers 

        private void Form1_Load(object sender, System.EventArgs e)
        {
            try
            {
                HandleRowUpdatedEvents();
                LoadData();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString(), "Error");
            }
        }

        /// <summary>
        /// Raised after a parent row is saved to the database.
        /// </summary>
        /// <param name="sender">
        /// The adapter that saved the row.
        /// </param>
        /// <param name="e">
        /// The data for the event.
        /// </param>
        /// <remarks>
        /// This event handler is used to retrieve an auto-generated ID from the database after a row is inserted and update the corresponding row in the local data set.
        /// </remarks>
        private void parentAdapter_RowUpdated(object sender, OleDbRowUpdatedEventArgs e)
        {
            // We are only interested in new records.
            if (e.StatementType == StatementType.Insert)
            {
                // Get the last ID auto-generated by the database.
                var lastAutoNumber = this.parentAdapter.GetLastAutoNumber().Value;

                // Update the ID of the local row.
                ((ParentChildDataSet.ParentRow) e.Row).ParentID = lastAutoNumber;
            }
        }

        /// <summary>
        /// Raised after a child row is saved to the database.
        /// </summary>
        /// <param name="sender">
        /// The adapter that saved the row.
        /// </param>
        /// <param name="e">
        /// The data for the event.
        /// </param>
        /// <remarks>
        /// This event handler is used to retrieve an auto-generated ID from the database after a row is inserted and update the corresponding row in the local data set.
        /// </remarks>
        private void childAdapter_RowUpdated(object sender, OleDbRowUpdatedEventArgs e)
        {
            // We are only interested in new records.
            if (e.StatementType == StatementType.Insert)
            {
                // Get the last ID auto-generated by the database.
                var lastAutoNumber = this.childAdapter.GetLastAutoNumber().Value;

                // Update the ID of the local row.
                ((ParentChildDataSet.ChildRow)e.Row).ChildID = lastAutoNumber;
            }
        }

        /// <summary>
        /// Raised when the user clicks the Save button on the parent tool bar.
        /// </summary>
        /// <param name="sender">
        /// The Save button.
        /// </param>
        /// <param name="e">
        /// The data for the event.
        /// </param>
        /// <remarks>
        /// Saves all parent and child data.
        /// </remarks>
        private void SaveToolStripButton_Click(object sender, System.EventArgs e)
        {
            if (this.Validate())
            {
                this.parentBindingSource.EndEdit();
                this.childBindingSource.EndEdit();

                this.adapterManager.UpdateAll(this.dataSet);
            }
        }

    #endregion //Event Handlers

    #region  Methods

        /// <summary>
        /// Attaches handlers to the RowUpdated events of the adapters.
        /// </summary>
        private void HandleRowUpdatedEvents()
        {
            this.parentAdapter.Adapter.RowUpdated += parentAdapter_RowUpdated;
            this.childAdapter.Adapter.RowUpdated += childAdapter_RowUpdated;
        }

        /// <summary>
        /// Retrieve the data from the database.
        /// </summary>
        private void LoadData()
        {
            this.parentAdapter.Fill(this.dataSet.Parent);
            this.childAdapter.Fill(this.dataSet.Child);
        }

    #endregion //Methods

        private static Form1 _DefaultInstance;
        public static Form1 DefaultInstance
        {
            get
            {
                if (_DefaultInstance == null)
                    _DefaultInstance = new Form1();

                return _DefaultInstance;
            }
        }
    }
}